@@ -1,3 +1,4 @@
+import requests
 import typing
 
 import audfactory
@@ -53,9 +54,12 @@ class Artifactory(Backend):
     ) -> bool:
         r"""Check if file exists on backend."""
         try:
-            # Can lead to RuntimeError: 404 page not found
+            # Can lead to
+            # RuntimeError: 404 page not found
+            # or
+            # requests.exceptions.HTTPError: 403 Client Error
             return audfactory.path(path).exists()
-        except RuntimeError:  # pragma: nocover
+        except self._non_existing_path_error:  # pragma: nocover
             return False
 
     def _get_file(
@@ -84,7 +88,7 @@ class Artifactory(Backend):
         path = audfactory.path(url)
         try:
             result = [str(x) for x in path.glob(pattern)]
-        except RuntimeError:  # pragma: no cover
+        except self._non_existing_path_error:  # pragma: nocover
             result = []
         return result
 
@@ -123,3 +127,18 @@ class Artifactory(Backend):
         r"""Versions of a file."""
         group_id = audfactory.path_to_group_id(folder)
         return audfactory.versions(self.host, self.repository, group_id, name)
+
+    _non_existing_path_error = (RuntimeError, requests.exceptions.HTTPError)
+    r"""Error expected for non-existing paths.
+
+    If a user has no permission to a given path
+    or the path does not exists :func:`audfactory.path`
+    might return a
+    ``RuntimeError: 404 page not found``
+    or
+    ``requests.exceptions.HTTPError: 403 Client Error``
+    error,
+    which might depend on the instaleld ``dohq-artifactory``
+    version. So we better catch both of them.
+
+    """
